@@ -98,9 +98,9 @@ class AutoDrawer:
 
     async def draw_and_fix(self, forever: bool = True):
         """Draw the pixels of the image, prioritise fixing existing ones."""
-        canvas = await self.client.get_canvas()
         work_to_do = True
         while work_to_do:
+            canvas = await self.client.get_canvas()
             work_to_do = False
             for x, y in self._iter_coords():
                 if await self.check_pixel(canvas, x, y):
@@ -109,5 +109,5 @@ class AutoDrawer:
                     break
             if forever and not work_to_do:
                 logger.info('Entire image is correct, waiting 1s to loop.')
-                asyncio.sleep(1)
+                await asyncio.sleep(1)
                 work_to_do = True
